@@ -18,7 +18,7 @@ use strict;
 use warnings;
 use Carp;
 use Exporter qw(import);
-use POSIX qw(:float_h isnan);
+use POSIX qw(:float_h);
 use Math::Complex qw();
 use Scalar::Util qw(looks_like_number);
 
@@ -27,7 +27,7 @@ use Math::MatrixDecomposition::Util qw(:all);
 
 BEGIN
 {
-  our $VERSION = '1.05';
+  our $VERSION = '1.06';
   our @EXPORT_OK = qw(eig);
 }
 
