@@ -16,8 +16,8 @@ use POSIX qw(fmod);
 
 BEGIN
 {
-  our $VERSION = '1.05';
-  our @EXPORT_OK = qw(eps mod min max sign hypot cdiv);
+  our $VERSION = '1.06';
+  our @EXPORT_OK = qw(eps isnan mod min max sign hypot cdiv);
   our %EXPORT_TAGS = (all => [@EXPORT_OK]);
 }
 
@@ -38,6 +38,14 @@ INIT
     }
 }
 
+# Not-a-number.
+sub isnan ($)
+{
+  my $x = shift;
+
+  $x != $x;
+}
+
 # Remainder of floating-point division.
 *mod = \&fmod;
 
@@ -146,6 +154,11 @@ Nothing is exported by default.
 Return the machine precision.
 
 
+=item C<isnan> (I<x>)
+
+Return true if I<x> is not-a-number.
+
+
 =item C<mod> (I<num>, I<den>)
 
 Return the remainder of a division.  Any argument can be either an
